@@ -285,12 +285,13 @@ void RGDebInstallProgress::conffile(gchar *conffile, gchar *status)
    RGGladeUserDialog dia(this, "conffile");
    GladeXML *xml = dia.getGladeXML();
 
-   p = g_strdup_printf(_("Install new configuration file\n'%s'?"),conffile);
+   p = g_strdup_printf(_("Replace configuration file\n'%s'?"),conffile);
    s = g_strdup_printf(_("The configuration file %s was modified (by "
 			 "you or by a script). An updated version is shipped "
 			 "in this package. If you want to keep your current "
-			 "version say 'No'. Do you want to install the "
-			 "new package maintainers version? "),conffile);
+			 "version say 'Keep'. Do you want to replace the "
+			 "current file and install the new package "
+			 "maintainers version? "),conffile);
 
    // setup dialog
    w = glade_xml_get_widget(xml, "label_message");
@@ -408,6 +409,14 @@ void RGDebInstallProgress::expander_callback (GObject    *object,
    gtk_widget_grab_focus(me->_term);
 }
 
+bool RGDebInstallProgress::close()
+{
+   if(child_has_exited)
+      cbClose(NULL, this);
+
+   return TRUE;
+}
+
 
 RGDebInstallProgress::RGDebInstallProgress(RGMainWindow *main,
 					   RPackageLister *lister,
